Learn R Programming

dagirlite (version 0.1.0)

kom_tabel: Data to change data from old county codes to new ones, from 2007

Description

Data to change data from old county codes to new ones, from 2007

Usage

data(kom_tabel)

Arguments

Format

A data frame with ? rows and ? variables:

X

x coordinate for centroid of old county

Y

y coordinate for centroid of old county

kode_f07

code for county before 2007

kommune

new county after 2007

kommune_f07

name for county before 2007

Examples

Run this code
# NOT RUN {
data(kom_tabel)


# }

Run the code above in your browser using DataLab